@@ -28,12 +28,14 @@
 
 #include <kdirlister.h>
 #include <kio/previewjob.h>
+#include <KIO/EmptyTrashJob>
 #include <kimagecache.h>
 
 DirModel::DirModel(QObject *parent)
     : KDirModel(parent),
       m_screenshotSize(180, 120)
 {
+#if 0 // unused here in trash
     QMimeDatabase db;
     QList<QMimeType> mimeList = db.allMimeTypes();
 
@@ -46,6 +48,7 @@ DirModel::DirModel(QObject *parent)
 
     //TODO: configurable mime filter
     //dirLister()->setMimeFilter(m_mimeTypes);
+#endif
 
     QHash<int, QByteArray>roleNames;
     roleNames[Qt::DisplayRole] = "display";
@@ -120,7 +123,7 @@ QVariantMap DirModel::get(int i) const
 
 void DirModel::emptyTrash()
 {
-    QProcess::startDetached(QStringLiteral("ktrash5 --empty"));
+    KIO::emptyTrash();
 }
 
 QVariant DirModel::data(const QModelIndex &index, int role) const
