@@ -154,7 +154,7 @@ public:
 
     void initQuery()
     {
-        if (query.isActive()) {
+        if (!database || query.isActive()) {
             return;
         }
 
@@ -202,6 +202,13 @@ public:
         return "resource GLOB '" + urlFilter + "'";
     }
 
+    QString mimetypeClause(const QString &mimetype) const
+    {
+        if (mimetype == ":any" || mimetype == "*") return "1";
+
+        return "mimetype GLOB '" + mimetype + "'";
+    }
+
     /**
      * Transforms the input list's elements with the f member method,
      * and returns the resulting list
@@ -252,6 +259,7 @@ public:
             "  , rl.usedActivity      as activity \n"
             "  , rl.initiatingAgent   as agent \n"
             "  , COALESCE(ri.title, rl.targettedResource) as title \n"
+            "  , ri.mimetype as mimetype \n"
 
             "FROM \n"
             "    ResourceLink rl \n"
@@ -268,6 +276,7 @@ public:
             "    ($agentsFilter) \n"
             "    AND ($activitiesFilter) \n"
             "    AND ($urlFilter)\n"
+            "    AND ($mimetypeFilter)\n"
 
             "GROUP BY resource, title \n"
             "ORDER BY $orderingColumn resource ASC \n"
@@ -295,6 +304,10 @@ public:
         QStringList urlFilter = transformedList(
                 queryDefinition.urlFilters(), &Private::urlFilterClause);
 
+        // WHERE clause for filtering on resource mime
+        QStringList mimetypeFilter = transformedList(
+                queryDefinition.types(), &Private::mimetypeClause);
+
         auto query = _query + limitOffsetSuffix();
 
         return
@@ -303,6 +316,7 @@ public:
                 .replace("$agentsFilter", agentsFilter.join(" OR "))
                 .replace("$activitiesFilter", activitiesFilter.join(" OR "))
                 .replace("$urlFilter", urlFilter.join(" OR "))
+                .replace("$mimetypeFilter", mimetypeFilter.join(" OR "))
             ;
     }
 
@@ -320,6 +334,7 @@ public:
             "  , rsc.usedActivity      as activity \n"
             "  , rsc.initiatingAgent   as agent \n"
             "  , COALESCE(ri.title, rsc.targettedResource) as title \n"
+            "  , ri.mimetype as mimetype \n"
 
             "FROM \n"
             "    ResourceScoreCache rsc \n"
@@ -331,6 +346,7 @@ public:
             "    ($agentsFilter) \n"
             "    AND ($activitiesFilter) \n"
             "    AND ($urlFilter)\n"
+            "    AND ($mimetypeFilter)\n"
 
             "GROUP BY resource, title \n"
             "ORDER BY $orderingColumn resource ASC\n"
@@ -359,15 +375,20 @@ public:
         QStringList urlFilter = transformedList(
                 queryDefinition.urlFilters(), &Private::urlFilterClause);
 
+        // WHERE clause for filtering on resource mime
+        QStringList mimetypeFilter = transformedList(
+                queryDefinition.types(), &Private::mimetypeClause);
+
         auto query = _query + limitOffsetSuffix();
 
-        return kamd::utils::debug_and_return("Query: ",
+        return  // kamd::utils::debug_and_return("Query: ",
             query
                 .replace("$orderingColumn", orderingColumn)
                 .replace("$agentsFilter", agentsFilter.join(" OR "))
                 .replace("$activitiesFilter", activitiesFilter.join(" OR "))
                 .replace("$urlFilter", urlFilter.join(" OR "))
-            );
+                .replace("$mimetypeFilter", mimetypeFilter.join(" OR "))
+            ;
     }
 
     QString allResourcesQuery() const
@@ -398,7 +419,14 @@ ResultSet::ResultSet(Query query)
     using namespace Common;
 
     d->database = Database::instance(Database::ResourcesDatabase, Database::ReadOnly);
-    Q_ASSERT_X(d->database, "ResultSet constructor", "Database is NULL");
+
+    if (!(d->database)) {
+        qWarning() << "KActivities ERROR: There is no database. This probably means "
+                      "that you do not have the Activity Manager running, or that "
+                      "something else is broken on your system. Recent documents and "
+                      "alike will not work!";
+        Q_ASSERT_X((bool)d->database, "ResultSet constructor", "Database is NULL");
+    }
 
     d->queryDefinition = query;
 
@@ -430,8 +458,6 @@ ResultSet::~ResultSet()
 ResultSet::Result ResultSet::at(int index) const
 {
     Q_ASSERT_X(d->query.isActive(), "ResultSet::at", "Query is not active");
-    // Q_ASSERT_X(d->query.size() >= 0, "ResultSet::at", "This query is not countable?!");
-    // Q_ASSERT_X(index < d->query.size(), "ResultSet::at", "This index does not exist");
 
     d->query.seek(index);
 
